==> openwebmail-2.10.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/it/htmlarea-lang.js <==
// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 pt)":  "1",
		"2 (10 pt)": "2",
		"3 (12 pt)": "3",
		"4 (14 pt)": "4",
		"5 (18 pt)": "5",
		"6 (24 pt)": "6",
		"7 (36 pt)": "7"
	},

	formatblock: {
		"Heading 1": "h1",
		"Heading 2": "h2",
		"Heading 3": "h3",
		"Heading 4": "h4",
		"Heading 5": "h5",
		"Heading 6": "h6",
		"Normal": "p",
		"Indirizzo": "address",
		"Impaginazione": "pre"
	},

	tooltips: {
		bold:           "Grassetto",
		italic:         "Italico",
		underline:      "Sottolineato",
		strikethrough:  "Barrato",
		subscript:      "Pedice",
		superscript:    "Apice",
		justifyleft:    "Allinea a sinistra",
		justifycenter:  "Allinea al centro",
		justifyright:   "Allinea a destra",
		justifyfull:    "Giustifica",
		orderedlist:    "Lista ordinata",
		unorderedlist:  "Lista a pallini",
		outdent:        "Riduci rientro",
		indent:         "Aumenta rientro",
		forecolor:      "Colore carattere",
		backcolor:      "Colore sfondo",
		horizontalrule: "Riga orizzontale",
		createlink:     "Inserisci Link Web",
		insertimage:    "Inserisci Immagine",
		insertsound:    "Inserisci Suono",
		inserttable:    "Inserisci Tabella",
		htmlmode:       "Togli sorgente HTML",
		popupeditor:    "Ingrandisci Editor",
		about:          "Informazioni su questo editor",
		help:           "Aiuto sull'editor",
		textindicator:  "Stile corrente"
	}
};

==> openwebmail-2.32.tgz: htdocs/openwebmail/javascript/htmlarea.openwebmail/popups/it/htmlarea-lang.js <==
// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Arial":           'arial,helvetica,sans-serif',
		"Courier New":     'courier new,courier,monospace',
		"Georgia":         'georgia,times new roman,times,serif',
		"Tahoma":          'tahoma,arial,helvetica,sans-serif',
		"Times New Roman": 'times new roman,times,serif',
		"Verdana":         'verdana,arial,helvetica,sans-serif',
		"impact":          'impact',
		"WingDings":       'wingdings'
	},

	fontsize: {
		"1 (8 pt)":  "1",
		"2 (10 pt)": "2",
		"3 (12 pt)": "3",
		"4 (14 pt)": "4",
		"5 (18 pt)": "5",
		"6 (24 pt)": "6",
		"7 (36 pt)": "7"
	},

	formatblock: {
		"Heading 1": "h1",
		"Heading 2": "h2",
		"Heading 3": "h3",
		"Heading 4": "h4",
		"Heading 5": "h5",
		"Heading 6": "h6",
		"Normal": "p",
		"Indirizzo": "address",
		"Impaginazione": "pre"
	},

	tooltips: {
		bold:           "Grassetto",
		italic:         "Italico",
		underline:      "Sottolineato",
		strikethrough:  "Barrato",
		subscript:      "Pedice",
		superscript:    "Apice",
		justifyleft:    "Allinea a sinistra",
		justifycenter:  "Allinea al centro",
		justifyright:   "Allinea a destra",
		justifyfull:    "Giustifica",
		insertorderedlist:    "Lista ordinata",
		insertunorderedlist:  "Lista a pallini",
		outdent:        "Riduci rientro",
		indent:         "Aumenta rientro",
		forecolor:      "Colore carattere",
		hilitecolor:    "Colore sfondo",
		horizontalrule: "Riga orizzontale",
		createlink:     "Inserisci Link Web",
		insertimage:    "Inserisci Immagine",
		insertsound:    "Inserisci Suono",
		inserttable:    "Inserisci Tabella",
		htmlmode:       "Togli sorgente HTML",
		popupeditor:    "Ingrandisci Editor",
		about:          "Informazioni su questo editor",
		showhelp:       "Aiuto sull'editor",
		textindicator:  "Stile corrente",
		undo:           "Undoes your last action",
		redo:           "Redoes your last action",
		cut:            "Cut selection",
		copy:           "Copy selection",
		paste:          "Paste from clipboard"
	},

	buttons: {
		"ok":           "OK",
		"cancel":       "Cancel"
	},

	msg: {
		"Path":         "Path",
		"TEXT_MODE":    "You are in TEXT MODE.  Use the [<>] button to switch back to WYSIWIG."
	}
};
